@@ -20,8 +20,9 @@ from sage.structure.unique_representation import UniqueRepresentation
 from sage.categories.algebras import Algebras
 from sage.categories.realizations import Realizations, Category_realization_of_parent
 from sage.categories.all import FiniteDimensionalAlgebrasWithBasis
-from sage.rings.all import ZZ, QQ
-from sage.functions.other import factorial
+from sage.rings.integer_ring import ZZ
+from sage.rings.rational_field import QQ
+from sage.arith.misc import factorial
 from sage.combinat.free_module import CombinatorialFreeModule
 from sage.combinat.permutation import Permutations
 from sage.combinat.composition import Compositions
@@ -720,9 +721,9 @@ class DescentAlgebra(UniqueRepresentation, Parent):
                 sage: DescentAlgebra(QQ, 4).I().one_basis()
                 Traceback (most recent call last):
                 ...
-                TypeError: 1 is not a basis element in the I basis.
+                TypeError: 1 is not a basis element in the I basis
             """
-            raise TypeError("1 is not a basis element in the I basis.")
+            raise TypeError("1 is not a basis element in the I basis")
 
         @cached_method
         def to_B_basis(self, p):
