@@ -52,11 +52,12 @@ Functions
 
 from sage.categories.sets_cat import EmptySetError
 from sage.misc.unknown import Unknown
-from .design_catalog import transversal_design
+from .design_catalog import transversal_design  # type: ignore
 from sage.arith.all import binomial, is_prime_power
 from .group_divisible_designs import GroupDivisibleDesign
 from .designs_pyx import is_pairwise_balanced_design
 
+
 def biplane(n, existence=False):
     r"""
     Return a biplane of order `n`.
@@ -721,10 +722,10 @@ def BIBD_from_difference_family(G, D, lambd=None, check=True):
     identity, mul, inv = group_law(G)
     bibd = []
     Gset = set(G)
-    p_to_i = {g:i for i,g in enumerate(Gset)}
+    p_to_i = {g: i for i, g in enumerate(Gset)}
     for b in D:
-        b = [G(_) for _ in b]
-        S = block_stabilizer(G,b)
+        b = [G(w) for w in b]
+        S = block_stabilizer(G, b)
         GG = Gset.copy()
         while GG:
             g = GG.pop()
@@ -839,7 +840,8 @@ def v_4_1_BIBD(v, check=True):
 
     return bibd
 
-def BIBD_from_PBD(PBD,v,k,check=True,base_cases={}):
+
+def BIBD_from_PBD(PBD, v, k, check=True, base_cases=None):
     r"""
     Return a `(v,k,1)`-BIBD from a `(r,K)`-PBD where `r=(v-1)/(k-1)`.
 
@@ -867,6 +869,8 @@ def BIBD_from_PBD(PBD,v,k,check=True,base_cases={}):
         sage: PBD = PBD_4_5_8_9_12(17)
         sage: bibd = is_pairwise_balanced_design(BIBD_from_PBD(PBD,52,4),52,[4])
     """
+    if base_cases is None:
+        base_cases = {}
     r = (v-1) // (k-1)
     bibd = []
     for X in PBD:
@@ -958,7 +962,7 @@ def PBD_4_5_8_9_12(v, check=True):
         sage: for v in (0,1,4,5,8,9,12,13,16,17,20,21,24,25):
         ....:     _ = PBD_4_5_8_9_12(v)
     """
-    if not v%4 in [0,1]:
+    if v % 4 not in [0, 1]:
         raise ValueError
     if v <= 1:
         PBD = []
