@@ -22,17 +22,17 @@ import builtins
 import os
 import sys
 import shutil
-import pkgconfig
 
 from sage.env import (SAGE_LOCAL, cython_aliases,
-                      sage_include_directories, get_cblas_pc_module_name)
-from sage.misc.misc import SPYX_TMP, sage_makedirs
+                      sage_include_directories)
+from sage.misc.misc import SPYX_TMP
 from .temporary_file import tmp_filename
 from sage.repl.user_globals import get_globals
 from sage.misc.sage_ostools import restore_cwd, redirection
 from sage.cpython.string import str_to_bytes
 from sage.misc.cachefunc import cached_function
 
+
 @cached_function
 def _standard_libs_libdirs_incdirs_aliases():
     r"""
@@ -53,7 +53,10 @@ def _standard_libs_libdirs_incdirs_aliases():
         'ec', 'gsl',
     ] + aliases["CBLAS_LIBRARIES"] + [
         'ntl']
-    standard_libdirs = [os.path.join(SAGE_LOCAL, "lib")] + aliases["CBLAS_LIBDIR"] + aliases["NTL_LIBDIR"]
+    standard_libdirs = []
+    if SAGE_LOCAL:
+        standard_libdirs.append(os.path.join(SAGE_LOCAL, "lib"))
+    standard_libdirs.extend(aliases["CBLAS_LIBDIR"] + aliases["NTL_LIBDIR"])
     standard_incdirs = sage_include_directories() + aliases["CBLAS_INCDIR"] + aliases["NTL_INCDIR"]
     return standard_libs, standard_libdirs, standard_incdirs, aliases
 
@@ -70,6 +73,7 @@ def _standard_libs_libdirs_incdirs_aliases():
 #
 ################################################################
 
+
 sequence_number = {}
 
 
@@ -254,7 +258,7 @@ def cython(filename, verbose=0, compile_message=False,
             except OSError:
                 pass
     else:
-        sage_makedirs(target_dir)
+        os.makedirs(target_dir, exist_ok=True)
 
     if create_local_so_file:
         name = base
@@ -328,10 +332,8 @@ def cython(filename, verbose=0, compile_message=False,
         # probability thereof, especially in normal practice.
         dll_filename = os.path.splitext(pyxfile)[0] + '.dll'
         image_base = _compute_dll_image_base(dll_filename)
-        extra_link_args.extend([
-                '-Wl,--disable-auto-image-base',
-                '-Wl,--image-base=0x{:x}'.format(image_base)
-        ])
+        extra_link_args.extend(['-Wl,--disable-auto-image-base',
+                                '-Wl,--image-base=0x{:x}'.format(image_base)])
 
     ext = Extension(name,
                     sources=[pyxfile],
